PurescriptTokenType

Enum PurescriptTokenType 

pub enum PurescriptTokenType {
Show 84 variants Whitespace, Newline, Comment, Ado, Case, Class, Data, Derive, Do, Else, False, Forall, Foreign, If, Import, In, Infix, Infixl, Infixr, Instance, Let, Module, Newtype, Of, Then, True, Type, Where, Arrow, FatArrow, Backslash, Pipe, Equal, ColonColon, Dot, DotDot, Plus, Minus, Star, Slash, Percent, Caret, EqualEqual, NotEqual, Less, Greater, LessEqual, GreaterEqual, And, Or, Append, Compose, ComposeFlipped, Apply, ApplyFlipped, Bind, BindFlipped, LeftParen, RightParen, LeftBrace, RightBrace, LeftBracket, RightBracket, Comma, Semicolon, Colon, Question, Exclamation, At, Underscore, Tick, IntLiteral, NumberLiteral, StringLiteral, CharLiteral, BooleanLiteral, Identifier, UpperIdentifier, Operator, QualifiedIdentifier, Root, SourceFile, Error, Eof,
}
Token types for PureScript.

Variants



Whitespace

Whitespace.



Newline

Newline.



Comment

Comment.



Ado

ado



Case

case



Class

class



Data

data



Derive

derive



Do

do



Else

else



False

false



Forall

forall



Foreign

foreign



If

if



Import

import



In

in



Infix

infix



Infixl

infixl



Infixr

infixr



Instance

instance



Let

let



Module

module



Newtype

newtype



Of

of



Then

then



True

true



Type

type



Where

where



Arrow

->



FatArrow

=>



Backslash

\



Pipe

|



Equal

=



ColonColon

::



Dot

.



DotDot

..



Plus

+



Minus

-



Star

*



Slash

/



Percent

%



Caret

^



EqualEqual

==



NotEqual

/=



Less

<



Greater

>



LessEqual

<=



GreaterEqual

>=



And

&&



Or

||



Append

<>



Compose

<<<



ComposeFlipped

>>>



Apply

$



ApplyFlipped

#



Bind

>>=



BindFlipped

=<<



LeftParen

(



RightParen

)



LeftBrace

{



RightBrace

}



LeftBracket

[



RightBracket

]



Comma

,



Semicolon

;



Colon

:



Question

?



Exclamation

!



At

@



Underscore

_



Tick

`



IntLiteral

Integer literal.



NumberLiteral

Floating point literal.



StringLiteral

String literal.



CharLiteral

Character literal.



BooleanLiteral

Boolean literal.



Identifier

Lowercase identifier.



UpperIdentifier

Uppercase identifier.



Operator

Operator.



QualifiedIdentifier

Qualified identifier.



Root

Root node.



SourceFile

Source file node.



Error

Error token.



Eof

End of file.