Purescript LSP Highlighter
Purescript syntax highlighter.
This module provides syntax highlighting for Purescript source code, supporting keywords, types, comments, etc.
This module provides purescript lsp highlighter functionality for the Oaks project.