PurescriptElementType

Enum PurescriptElementType 

pub enum PurescriptElementType {
Show 111 variants Whitespace, Newline, Comment, Ado, Case, Class, Data, Derive, Do, Else, False, Forall, Foreign, If, Import, In, Infix, Infixl, Infixr, Instance, Let, Module, Newtype, Of, Then, True, Type, Where, Arrow, FatArrow, Backslash, Pipe, Equal, ColonColon, Dot, DotDot, Plus, Minus, Star, Slash, Percent, Caret, EqualEqual, NotEqual, Less, Greater, LessEqual, GreaterEqual, And, Or, Not, LeftParen, RightParen, LeftBracket, RightBracket, LeftBrace, RightBrace, Comma, Semicolon, Colon, Dollar, Append, LeftArrow, Underscore, Identifier, Constructor, Operator, StringLiteral, IntLiteral, NumberLiteral, CharLiteral, ModuleDeclaration, ImportDeclaration, DataDeclaration, NewtypeDeclaration, TypeAliasDeclaration, ClassDeclaration, InstanceDeclaration, ForeignImportDeclaration, TypeSignature, ValueDeclaration, Pattern, Expression, LiteralExpression, IdentifierExpression, PrefixExpression, InfixExpression, ApplicationExpression, LambdaExpression, LetExpression, CaseExpression, CaseArm, DoExpression, TypeNode, SourceFile, Compose, ComposeFlipped, Apply, ApplyFlipped, Bind, BindFlipped, Question, Exclamation, At, Tick, UpperIdentifier, QualifiedIdentifier, BooleanLiteral, Root, Eof, Error,
}
Element types for PureScript AST.

Variants



Whitespace

Whitespace.



Newline

Newline.



Comment

Comment.



Ado

ado



Case

case



Class

class



Data

data



Derive

derive



Do

do



Else

else



False

false



Forall

forall



Foreign

foreign



If

if



Import

import



In

in



Infix

infix



Infixl

infixl



Infixr

infixr



Instance

instance



Let

let



Module

module



Newtype

newtype



Of

of



Then

then



True

true



Type

type



Where

where



Arrow

->



FatArrow

=>



Backslash

\



Pipe

|



Equal

=



ColonColon

::



Dot

.



DotDot

..



Plus

+



Minus

-



Star

*



Slash

/



Percent

%



Caret

^



EqualEqual

==



NotEqual

/=



Less

<



Greater

>



LessEqual

<=



GreaterEqual

>=



And

&&



Or

||



Not

!



LeftParen

(



RightParen

)



LeftBracket

[



RightBracket

]



LeftBrace

{



RightBrace

}



Comma

,



Semicolon

;



Colon

:



Dollar

$



Append

<>



LeftArrow

<-



Underscore

_



Identifier

Identifier.



Constructor

Constructor.



Operator

Operator.



StringLiteral

String literal.



IntLiteral

Integer literal.



NumberLiteral

Float literal.



CharLiteral

Char literal.



ModuleDeclaration

A module declaration.



ImportDeclaration

An import declaration.



DataDeclaration

A data declaration.



NewtypeDeclaration

A newtype declaration.



TypeAliasDeclaration

A type alias declaration.



ClassDeclaration

A class declaration.



InstanceDeclaration

An instance declaration.



ForeignImportDeclaration

A foreign import declaration.



TypeSignature

A type signature.



ValueDeclaration

A value declaration.



Pattern

A pattern.



Expression

An expression.



LiteralExpression

A literal expression.



IdentifierExpression

An identifier expression.



PrefixExpression

A prefix expression.



InfixExpression

An infix expression.



ApplicationExpression

A function application.



LambdaExpression

A lambda expression.



LetExpression

A let expression.



CaseExpression

A case expression.



CaseArm

A case arm.



DoExpression

A do expression.



TypeNode

A type.



SourceFile

Source file node.



Compose

<<<



ComposeFlipped

>>>



Apply

$



ApplyFlipped

#



Bind

>>=



BindFlipped

=<<



Question

?



Exclamation

!



At

@



Tick

Backtick



UpperIdentifier

Upper case identifier



QualifiedIdentifier

Qualified identifier



BooleanLiteral

Boolean literal



Root

Root node



Eof

End of file



Error

Error node.